==> ui-v0.1.0.zip: delfi/ui/app/pages/home.jsx <==
import React, { useState, useEffect } from 'react'
import {Link} from 'react-router-dom';

import {
    getStopsCountGtfsDeNotDhid,
    getStopsCountGtfsDeHbNotDhid,
    getStopsCountGtfsDeHhNotDhid,
    getStopsCountGtfsDeNiNotDhid,
    getStopsCountGtfsDeShNotDhid,
    getStopsCountGtfsDeMvNotDhid,
    getStopsCountGtfsDeBbNotDhid,
    getStopsCountGtfsDeBeNotDhid,
    getStopsCountGtfsDeStNotDhid,
    getStopsCountGtfsDeNwNotDhid,
    getStopsCountGtfsDeHeNotDhid,
    getStopsCountGtfsDeSnNotDhid,
    getStopsCountGtfsDeThNotDhid,
    getStopsCountGtfsDeRpNotDhid,
    getStopsCountGtfsDeSlNotDhid,
    getStopsCountGtfsDeByNotDhid,
    getStopsCountGtfsDeBwNotDhid,
    getStopsCountGtfs,
    getStopsCountGtfsDe,
    getStopsCountGtfsDeHb,
    getStopsCountGtfsDeHh,
    getStopsCountGtfsDeNi,
    getStopsCountGtfsDeSh,
    getStopsCountGtfsDeMv,
    getStopsCountGtfsDeBb,
    getStopsCountGtfsDeBe,
    getStopsCountGtfsDeSt,
    getStopsCountGtfsDeNw,
    getStopsCountGtfsDeHe,
    getStopsCountGtfsDeSn,
    getStopsCountGtfsDeTh,
    getStopsCountGtfsDeRp,
    getStopsCountGtfsDeSl,
    getStopsCountGtfsDeBy,
    getStopsCountGtfsDeBw
} from '../utils/api';

export default function Home(){
    const [countStopsGtfs, setCountStopsGtfs] = useState('loading...');

    const [countStopsGtfsDe, setCountStopsGtfsDe] = useState('loading...');
    const [countStopsGtfsDeHb, setCountStopsGtfsDeHb] = useState('loading...');
    const [countStopsGtfsDeHh, setCountStopsGtfsDeHh] = useState('loading...');
    const [countStopsGtfsDeNi, setCountStopsGtfsDeNi] = useState('loading...');
    const [countStopsGtfsDeSh, setCountStopsGtfsDeSh] = useState('loading...');
    const [countStopsGtfsDeMv, setCountStopsGtfsDeMv] = useState('loading...');
    const [countStopsGtfsDeBb, setCountStopsGtfsDeBb] = useState('loading...');
    const [countStopsGtfsDeBe, setCountStopsGtfsDeBe] = useState('loading...');
    const [countStopsGtfsDeSt, setCountStopsGtfsDeSt] = useState('loading...');
    const [countStopsGtfsDeNw, setCountStopsGtfsDeNw] = useState('loading...');
    const [countStopsGtfsDeHe, setCountStopsGtfsDeHe] = useState('loading...');
    const [countStopsGtfsDeSn, setCountStopsGtfsDeSn] = useState('loading...');
    const [countStopsGtfsDeTh, setCountStopsGtfsDeTh] = useState('loading...');
    const [countStopsGtfsDeRp, setCountStopsGtfsDeRp] = useState('loading...');
    const [countStopsGtfsDeSl, setCountStopsGtfsDeSl] = useState('loading...');
    const [countStopsGtfsDeBy, setCountStopsGtfsDeBy] = useState('loading...');
    const [countStopsGtfsDeBw, setCountStopsGtfsDeBw] = useState('loading...');

    const [countStopsGtfsDeNotDhid, setCountStopsGtfsDeNotDhid] = useState('loading...');
    const [countStopsGtfsDeHbNotDhid, setCountStopsGtfsDeHbNotDhid] = useState('loading...');
    const [countStopsGtfsDeHhNotDhid, setCountStopsGtfsDeHhNotDhid] = useState('loading...');
    const [countStopsGtfsDeNiNotDhid, setCountStopsGtfsDeNiNotDhid] = useState('loading...');
    const [countStopsGtfsDeShNotDhid, setCountStopsGtfsDeShNotDhid] = useState('loading...');
    const [countStopsGtfsDeMvNotDhid, setCountStopsGtfsDeMvNotDhid] = useState('loading...');
    const [countStopsGtfsDeBbNotDhid, setCountStopsGtfsDeBbNotDhid] = useState('loading...');
    const [countStopsGtfsDeBeNotDhid, setCountStopsGtfsDeBeNotDhid] = useState('loading...');
    const [countStopsGtfsDeStNotDhid, setCountStopsGtfsDeStNotDhid] = useState('loading...');
    const [countStopsGtfsDeNwNotDhid, setCountStopsGtfsDeNwNotDhid] = useState('loading...');
    const [countStopsGtfsDeHeNotDhid, setCountStopsGtfsDeHeNotDhid] = useState('loading...');
    const [countStopsGtfsDeSnNotDhid, setCountStopsGtfsDeSnNotDhid] = useState('loading...');
    const [countStopsGtfsDeThNotDhid, setCountStopsGtfsDeThNotDhid] = useState('loading...');
    const [countStopsGtfsDeRpNotDhid, setCountStopsGtfsDeRpNotDhid] = useState('loading...');
    const [countStopsGtfsDeSlNotDhid, setCountStopsGtfsDeSlNotDhid] = useState('loading...');
    const [countStopsGtfsDeByNotDhid, setCountStopsGtfsDeByNotDhid] = useState('loading...');
    const [countStopsGtfsDeBwNotDhid, setCountStopsGtfsDeBwNotDhid] = useState('loading...');

    const fetchGtfs = async () => {
	let count=await getStopsCountGtfs();
	if(count > -1){
	    setCountStopsGtfs((countStopsGtfs) => count);
	}
    };

    const fetchGtfsDe = async () => {
	let count=await getStopsCountGtfsDe();
	if(count > -1){
	    setCountStopsGtfsDe((countStopsGtfsDe) => count);
	}
    };

    const fetchGtfsDeHb = async () => {
	let count=await getStopsCountGtfsDeHb();
	if(count > -1){
	    setCountStopsGtfsDeHb((countStopsGtfsDeHb) => count);
	}
    };

    const fetchGtfsDeHh = async () => {
	let count=await getStopsCountGtfsDeHh();
	if(count > -1){
	    setCountStopsGtfsDeHh((countStopsGtfsDeHh) => count);
	}
    };

    const fetchGtfsDeNi = async () => {
	let count=await getStopsCountGtfsDeNi();
	if(count > -1){
	    setCountStopsGtfsDeNi((countStopsGtfsDeNi) => count);
	}
    };

    const fetchGtfsDeNotDhid = async () => {
	let count=await getStopsCountGtfsDeNotDhid();
	if(count > -1){
	    setCountStopsGtfsDeNotDhid((countStopsGtfsDeNotDhid) => count);
	}
    };

    const fetchGtfsDeHbNotDhid = async () => {
	let count=await getStopsCountGtfsDeHbNotDhid();
	if(count > -1){
	    setCountStopsGtfsDeHbNotDhid((countStopsGtfsDeHbNotDhid) => count);
	}
    };

    const fetchGtfsDeHhNotDhid = async () => {
	let count=await getStopsCountGtfsDeHhNotDhid();
	if(count > -1){
	    setCountStopsGtfsDeHhNotDhid((countStopsGtfsDeHhNotDhid) => count);
	}
    };

    const fetchGtfsDeNiNotDhid = async () => {
	let count=await getStopsCountGtfsDeNiNotDhid();
	if(count > -1){
	    setCountStopsGtfsDeNiNotDhid(count);
	}
    };

    const fetchGtfsDeShNotDhid = async () => {
	let count=await getStopsCountGtfsDeShNotDhid();
	if(count > -1){
	    setCountStopsGtfsDeShNotDhid(count);
	}
    };

    const fetchGtfsDeSh = async () => {
	let count=await getStopsCountGtfsDeSh();
	if(count > -1){
	    setCountStopsGtfsDeSh(count);
	}
    };

    const fetchGtfsDeMvNotDhid = async () => {
	let count=await getStopsCountGtfsDeMvNotDhid();
	if(count > -1){
	    setCountStopsGtfsDeMvNotDhid(count);
	}
    };

    const fetchGtfsDeMv = async () => {
	let count=await getStopsCountGtfsDeMv();
	if(count > -1){
	    setCountStopsGtfsDeMv(count);
	}
    };

    const fetchGtfsDeBbNotDhid = async () => {
	let count=await getStopsCountGtfsDeBbNotDhid();
	if(count > -1){
	    setCountStopsGtfsDeBbNotDhid(count);
	}
    };

    const fetchGtfsDeBb = async () => {
	let count=await getStopsCountGtfsDeBb();
	if(count > -1){
	    setCountStopsGtfsDeBb(count);
	}
    };

    const fetchGtfsDeBeNotDhid = async () => {
	let count=await getStopsCountGtfsDeBeNotDhid();
	if(count > -1){
	    setCountStopsGtfsDeBeNotDhid(count);
	}
    };

    const fetchGtfsDeBe = async () => {
	let count=await getStopsCountGtfsDeBe();
	if(count > -1){
	    setCountStopsGtfsDeBe(count);
	}
    };

    const fetchGtfsDeStNotDhid = async () => {
	let count=await getStopsCountGtfsDeStNotDhid();
	if(count > -1){
	    setCountStopsGtfsDeStNotDhid(count);
	}
    };

    const fetchGtfsDeSt = async () => {
	let count=await getStopsCountGtfsDeSt();
	if(count > -1){
	    setCountStopsGtfsDeSt(count);
	}
    };

    const fetchGtfsDeNwNotDhid = async () => {
	let count=await getStopsCountGtfsDeNwNotDhid();
	if(count > -1){
	    setCountStopsGtfsDeNwNotDhid(count);
	}
    };

    const fetchGtfsDeNw = async () => {
	let count=await getStopsCountGtfsDeNw();
	if(count > -1){
	    setCountStopsGtfsDeNw(count);
	}
    };

    const fetchGtfsDeHeNotDhid = async () => {
	let count=await getStopsCountGtfsDeHeNotDhid();
	if(count > -1){
	    setCountStopsGtfsDeHeNotDhid(count);
	}
    };

    const fetchGtfsDeHe = async () => {
	let count=await getStopsCountGtfsDeHe();
	if(count > -1){
	    setCountStopsGtfsDeHe(count);
	}
    };

    const fetchGtfsDeSnNotDhid = async () => {
	let count=await getStopsCountGtfsDeSnNotDhid();
	if(count > -1){
	    setCountStopsGtfsDeSnNotDhid(count);
	}
    };

    const fetchGtfsDeSn = async () => {
	let count=await getStopsCountGtfsDeSn();
	if(count > -1){
	    setCountStopsGtfsDeSn(count);
	}
    };

    const fetchGtfsDeThNotDhid = async () => {
	let count=await getStopsCountGtfsDeThNotDhid();
	if(count > -1){
	    setCountStopsGtfsDeThNotDhid(count);
	}
    };

    const fetchGtfsDeTh = async () => {
	let count=await getStopsCountGtfsDeTh();
	if(count > -1){
	    setCountStopsGtfsDeTh(count);
	}
    };

    const fetchGtfsDeRpNotDhid = async () => {
	let count=await getStopsCountGtfsDeRpNotDhid();
	if(count > -1){
	    setCountStopsGtfsDeRpNotDhid(count);
	}
    };

    const fetchGtfsDeRp = async () => {
	let count=await getStopsCountGtfsDeRp();
	if(count > -1){
	    setCountStopsGtfsDeRp(count);
	}
    };

    const fetchGtfsDeSlNotDhid = async () => {
	let count=await getStopsCountGtfsDeSlNotDhid();
	if(count > -1){
	    setCountStopsGtfsDeSlNotDhid(count);
	}
    };

    const fetchGtfsDeSl = async () => {
	let count=await getStopsCountGtfsDeSl();
	if(count > -1){
	    setCountStopsGtfsDeSl(count);
	}
    };

    const fetchGtfsDeByNotDhid = async () => {
	let count=await getStopsCountGtfsDeByNotDhid();
	if(count > -1){
	    setCountStopsGtfsDeByNotDhid(count);
	}
    };

    const fetchGtfsDeBy = async () => {
	let count=await getStopsCountGtfsDeBy();
	if(count > -1){
	    setCountStopsGtfsDeBy(count);
	}
    };

    const fetchGtfsDeBwNotDhid = async () => {
	let count=await getStopsCountGtfsDeBwNotDhid();
	if(count > -1){
	    setCountStopsGtfsDeBwNotDhid(count);
	}
    };

    const fetchGtfsDeBw = async () => {
	let count=await getStopsCountGtfsDeBw();
	if(count > -1){
	    setCountStopsGtfsDeBw(count);
	}
    };

    useEffect(() => {
	/*effect goes here*/

	fetchGtfs();
	fetchGtfsDe();
	fetchGtfsDeHb();
	fetchGtfsDeHh();
	fetchGtfsDeNi();
	fetchGtfsDeSh();
	fetchGtfsDeMv();
	fetchGtfsDeBb();
	fetchGtfsDeBe();
	fetchGtfsDeSt();
	fetchGtfsDeNw();
	fetchGtfsDeHe();
	fetchGtfsDeSn();
	fetchGtfsDeTh();
	fetchGtfsDeRp();
	fetchGtfsDeSl();
	fetchGtfsDeBy();
	fetchGtfsDeBw();

	fetchGtfsDeNotDhid();
	fetchGtfsDeHbNotDhid();
	fetchGtfsDeHhNotDhid();
	fetchGtfsDeNiNotDhid();
	fetchGtfsDeShNotDhid();
	fetchGtfsDeMvNotDhid();
	fetchGtfsDeBbNotDhid();
	fetchGtfsDeBeNotDhid();
	fetchGtfsDeStNotDhid();
	fetchGtfsDeNwNotDhid();
	fetchGtfsDeHeNotDhid();
	fetchGtfsDeSnNotDhid();
	fetchGtfsDeThNotDhid();
	fetchGtfsDeRpNotDhid();
	fetchGtfsDeSlNotDhid();
	fetchGtfsDeByNotDhid();
	fetchGtfsDeBwNotDhid();
	/*use an empty dependency countStopsGtfs to ensure the hook is running only once*/
	/*TODO study dependency countStopsGtfs: https://reactjs.org/docs/hooks-effect.html*/
    }, []);

    return (
	<>
	    <p>
		Number of stops:&nbsp;
		{countStopsGtfs}
	    </p>
	    <p>
		Number of stops inside DE:&nbsp;
		{countStopsGtfsDe}
	    </p>
	    <p>
		Number of stops inside DE not compliant with the Global ID:&nbsp;
		{countStopsGtfsDeNotDhid} ({countStopsGtfsDe !== 0 ? (countStopsGtfsDeNotDhid / countStopsGtfsDe * 100).toFixed(3) : 'loading...'} %)
	    </p>
	    <p>
		Number of stops inside DE-HB:&nbsp;
		{countStopsGtfsDeHb}
	    </p>
	    <p>
		Number of stops inside DE-HB not compliant with the Global ID:&nbsp;
		{countStopsGtfsDeHbNotDhid} ({countStopsGtfsDeHb !== 0 ? (countStopsGtfsDeHbNotDhid / countStopsGtfsDeHb * 100).toFixed(3) : 'loading...'} %)
	    </p>
	    <p>
		Number of stops inside DE-HH:&nbsp;
		{countStopsGtfsDeHh}
	    </p>
	    <p>
		Number of stops inside DE-HH not compliant with the Global ID:&nbsp;
		{countStopsGtfsDeHhNotDhid} ({countStopsGtfsDeHh !== 0 ? (countStopsGtfsDeHhNotDhid / countStopsGtfsDeHh * 100).toFixed(3) : 'loading...'} %)
	    </p>
	    <p>
		Number of stops inside DE-NI:&nbsp;
		{countStopsGtfsDeNi}
	    </p>
	    <p>
		Number of stops inside DE-NI not compliant with the Global ID:&nbsp;
		{countStopsGtfsDeNiNotDhid} ({countStopsGtfsDeNi !== 0 ? (countStopsGtfsDeNiNotDhid / countStopsGtfsDeNi * 100).toFixed(3) : 'loading...'} %)
	    </p>
	    <p>
		Number of stops inside DE-SH:&nbsp;
		{countStopsGtfsDeSh}
	    </p>
	    <p>
		Number of stops inside DE-SH not compliant with the Global ID:&nbsp;
		{countStopsGtfsDeShNotDhid} ({countStopsGtfsDeSh !== 0 ? (countStopsGtfsDeShNotDhid / countStopsGtfsDeSh * 100).toFixed(3) : 'loading...'} %)
	    </p>
	    <p>
		Number of stops inside DE-MV:&nbsp;
		{countStopsGtfsDeMv}
	    </p>
	    <p>
		Number of stops inside DE-MV not compliant with the Global ID:&nbsp;
		{countStopsGtfsDeMvNotDhid} ({countStopsGtfsDeMv !== 0 ? (countStopsGtfsDeMvNotDhid / countStopsGtfsDeMv * 100).toFixed(3) : 'loading...'} %)
	    </p>
	    <p>
		Number of stops inside DE-BB:&nbsp;
		{countStopsGtfsDeBb}
	    </p>
	    <p>
		Number of stops inside DE-BB not compliant with the Global ID:&nbsp;
		{countStopsGtfsDeBbNotDhid} ({countStopsGtfsDeBb !== 0 ? (countStopsGtfsDeBbNotDhid / countStopsGtfsDeBb * 100).toFixed(3) : 'loading...'} %)
	    </p>
	    <p>
		Number of stops inside DE-BE:&nbsp;
		{countStopsGtfsDeBe}
	    </p>
	    <p>
		Number of stops inside DE-BE not compliant with the Global ID:&nbsp;
		{countStopsGtfsDeBeNotDhid} ({countStopsGtfsDeBe !== 0 ? (countStopsGtfsDeBeNotDhid / countStopsGtfsDeBe * 100).toFixed(3) : 'loading...'} %)
	    </p>
	    <p>
		Number of stops inside DE-ST:&nbsp;
		{countStopsGtfsDeSt}
	    </p>
	    <p>
		Number of stops inside DE-ST not compliant with the Global ID:&nbsp;
		{countStopsGtfsDeStNotDhid} ({countStopsGtfsDeSt !== 0 ? (countStopsGtfsDeStNotDhid / countStopsGtfsDeSt * 100).toFixed(3) : 'loading...'} %)
	    </p>
	    <p>
		Number of stops inside DE-NW:&nbsp;
		{countStopsGtfsDeNw}
	    </p>
	    <p>
		Number of stops inside DE-NW not compliant with the Global ID:&nbsp;
		{countStopsGtfsDeNwNotDhid} ({countStopsGtfsDeNw !== 0 ? (countStopsGtfsDeNwNotDhid / countStopsGtfsDeNw * 100).toFixed(3) : 'loading...'} %)
	    </p>
	    <p>
		Number of stops inside DE-HE:&nbsp;
		{countStopsGtfsDeHe}
	    </p>
	    <p>
		Number of stops inside DE-HE not compliant with the Global ID:&nbsp;
		{countStopsGtfsDeHeNotDhid} ({countStopsGtfsDeHe !== 0 ? (countStopsGtfsDeHeNotDhid / countStopsGtfsDeHe * 100).toFixed(3) : 'loading...'} %)
	    </p>
	    <p>
		Number of stops inside DE-SN:&nbsp;
		{countStopsGtfsDeSn}
	    </p>
	    <p>
		Number of stops inside DE-SN not compliant with the Global ID:&nbsp;
		{countStopsGtfsDeSnNotDhid} ({countStopsGtfsDeSn !== 0 ? (countStopsGtfsDeSnNotDhid / countStopsGtfsDeSn * 100).toFixed(3) : 'loading...'} %)
	    </p>
	    <p>
		Number of stops inside DE-TH:&nbsp;
		{countStopsGtfsDeTh}
	    </p>
	    <p>
		Number of stops inside DE-TH not compliant with the Global ID:&nbsp;
		{countStopsGtfsDeThNotDhid} ({countStopsGtfsDeTh !== 0 ? (countStopsGtfsDeThNotDhid / countStopsGtfsDeTh * 100).toFixed(3) : 'loading...'} %)
	    </p>
	    <p>
		Number of stops inside DE-RP:&nbsp;
		{countStopsGtfsDeRp}
	    </p>
	    <p>
		Number of stops inside DE-RP not compliant with the Global ID:&nbsp;
		{countStopsGtfsDeRpNotDhid} ({countStopsGtfsDeRp !== 0 ? (countStopsGtfsDeRpNotDhid / countStopsGtfsDeRp * 100).toFixed(3) : 'loading...'} %)
	    </p>
	    <p>
		Number of stops inside DE-SL:&nbsp;
		{countStopsGtfsDeSl}
	    </p>
	    <p>
		Number of stops inside DE-SL not compliant with the Global ID:&nbsp;
		{countStopsGtfsDeSlNotDhid} ({countStopsGtfsDeSl !== 0 ? (countStopsGtfsDeSlNotDhid / countStopsGtfsDeSl * 100).toFixed(3) : 'loading...'} %)
	    </p>
	    <p>
		Number of stops inside DE-BY:&nbsp;
		{countStopsGtfsDeBy}
	    </p>
	    <p>
		Number of stops inside DE-BY not compliant with the Global ID:&nbsp;
		{countStopsGtfsDeByNotDhid} ({countStopsGtfsDeBy !== 0 ? (countStopsGtfsDeByNotDhid / countStopsGtfsDeBy * 100).toFixed(3) : 'loading...'} %)
	    </p>
	    <p>
		Number of stops inside DE-BW:&nbsp;
		{countStopsGtfsDeBw}
	    </p>
	    <p>
		Number of stops inside DE-BW not compliant with the Global ID:&nbsp;
		{countStopsGtfsDeBwNotDhid} ({countStopsGtfsDeBw !== 0 ? (countStopsGtfsDeBwNotDhid / countStopsGtfsDeBw * 100).toFixed(3) : 'loading...'} %)
	    </p>
	    <h3>
	    <Link to="/stops-non-compliant">
		Browse through stops inside DE not compliant with the Global ID.
	    </Link>
	    </h3>
	    <h3>
	    <Link to="/stops-refined">
		Browse through stops inside DE refined to be compliant with the Global ID.
	    </Link>
	    </h3>
	</>
    );
}

==> ui-v0.5.0.zip: delfi/ui/app/pages/home.jsx <==
import React, { useState, useEffect } from 'react'
import {Link} from 'react-router-dom';

import State from '../components/state';
import {
    getStopsCountGtfs,
    getStopsCountGtfsDe,
    getStopsCountGtfsDeNotDhid,
    getStopsCountGtfsLt0
} from '../utils/api';

export default function Home(){

    const [countStopsGtfs, setCountStopsGtfs] = useState('loading...');
    const [countStopsGtfsLt0, setCountStopsGtfsLt0] = useState('loading...');
    const [countStopsGtfsDe, setCountStopsGtfsDe] = useState('loading...');
    const [countStopsGtfsDeNotDhid, setCountStopsGtfsDeNotDhid] = useState('loading...');

    const fetchGtfs = async () => {
	let count=await getStopsCountGtfs();
	if(count > -1){
	    setCountStopsGtfs((countStopsGtfs) => count);
	}
    };

    const fetchGtfsLt0 = async () => {
	let count=await getStopsCountGtfsLt0();
	if(count > -1){
	    setCountStopsGtfsLt0((countStopsGtfsLt0) => count);
	}
    };

    const fetchGtfsDe = async () => {
	let count=await getStopsCountGtfsDe();
	if(count > -1){
	    setCountStopsGtfsDe((countStopsGtfsDe) => count);
	}
    };

    const fetchGtfsDeNotDhid = async () => {
	let count=await getStopsCountGtfsDeNotDhid();
	if(count > -1){
	    setCountStopsGtfsDeNotDhid((countStopsGtfsDeNotDhid) => count);
	}
    };

    useEffect(() => {
	/*effect goes here*/
	fetchGtfs();
	fetchGtfsLt0();
	fetchGtfsDe();
	fetchGtfsDeNotDhid();
	/*use an empty dependency countStopsGtfs to ensure the hook is running only once*/
	/*TODO study dependency countStopsGtfs: https://reactjs.org/docs/hooks-effect.html*/
    }, []);

    return (
	<>
	    <p>
		Number of entries in the stops.txt file no matter the&nbsp;
	    <Link
		title="gtfs stops location type"
		target="_blank"
		rel="noopener noreferrer nofollow"
		to='https://gtfs.org/schedule/reference/#stopstxt'
	    >
		location type
	    </Link>
		:&nbsp;
		{countStopsGtfs}
	    </p>
	    <p>
		Starting here, only stops with location_type="0" are considered for further data analysis:&nbsp;
		{countStopsGtfsLt0}
	    </p>
	    <p>
		DE: Stops not compliant with the Global ID:&nbsp;
		{countStopsGtfsDeNotDhid} ({countStopsGtfsDe !== 0 ? (countStopsGtfsDeNotDhid / countStopsGtfsDe * 100).toFixed(3) : 'loading...'} %)
		(Stops overall:&nbsp;
		{countStopsGtfsDe})
	    </p>
	    <State state='bb' />
	    <State state='be' />
	    <State state='bw' />
	    <State state='by' />
	    <State state='hb' />
	    <State state='he' />
	    <State state='hh' />
	    <State state='mv' />
	    <State state='ni' />
	    <State state='nw' />
	    <State state='rp' />
	    <State state='sh' />
	    <State state='sl' />
	    <State state='sn' />
	    <State state='st' />
	    <State state='th' />
	    <h3>
	    <Link to="/stops-non-compliant">
		Browse through stops inside DE not compliant with the Global ID.
	    </Link>
	    </h3>
	    <h3>
	    <Link to="/stops-refined">
		Browse through stops inside DE refined to be compliant with the Global ID.
	    </Link>
	    </h3>
	</>
    );
}
